@@ -1,5 +1,6 @@
 import statsmodels.regression.linear_model as lm_
 import statsmodels.discrete.discrete_model as dm_
+import statsmodels.discrete.conditional_models as dcm_
 import statsmodels.regression.mixed_linear_model as mlm_
 import statsmodels.genmod.generalized_linear_model as glm_
 import statsmodels.robust.robust_linear_model as roblm_
@@ -26,10 +27,16 @@ ordinal_gee = gee_.OrdinalGEE.from_formula
 nominal_gee = gee_.NominalGEE.from_formula
 gee = gee_.GEE.from_formula
 glmgam = gam_.GLMGam.from_formula
+conditional_logit = dcm_.ConditionalLogit.from_formula
+conditional_mnlogit = dcm_.ConditionalMNLogit.from_formula
+conditional_poisson = dcm_.ConditionalPoisson.from_formula
 
-del lm_, dm_, mlm_, glm_, roblm_, qr_, hr_, gee_, gam_
+del lm_, dm_, mlm_, glm_, roblm_, qr_, hr_, gee_, gam_, dcm_
 
 __all__ = [
+    "conditional_logit",
+    "conditional_mnlogit",
+    "conditional_poisson",
     "gee",
     "glm",
     "glmgam",
