@@ -1,4 +1,4 @@
-'''
+"""
 This module contains the one-parameter exponential families used
 for fitting GLMs and GAMs.
 
@@ -8,9 +8,14 @@ These families are described in
    Monographs on Statistics and Applied Probability.
    Chapman & Hall, London, 1983.
 
-'''
+"""
 
-#from statsmodels.family.family import Gaussian, Family, Poisson, Gamma, \
-#    InverseGaussian, Binomial, NegativeBinomial
+from statsmodels.genmod.families import links
 from .family import Gaussian, Family, Poisson, Gamma, \
-    InverseGaussian, Binomial, NegativeBinomial
+    InverseGaussian, Binomial, NegativeBinomial, Tweedie
+from statsmodels.tools._test_runner import PytestTester
+
+__all__ = ['test', 'links', 'Family', 'Gamma', 'Gaussian', 'Poisson',
+           'InverseGaussian', 'Binomial', 'NegativeBinomial', 'Tweedie']
+
+test = PytestTester()
